Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(104)

Unified Diff: components/reading_list/core/reading_list_store.h

Issue 2923363004: [Sync] Migrate bridge implementations to change list based MergeSyncData (Closed)
Patch Set: Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/reading_list/core/reading_list_store.h
diff --git a/components/reading_list/core/reading_list_store.h b/components/reading_list/core/reading_list_store.h
index eca26da87d289ff8bba1cd104b02186c94f02da8..d3016f692a67871b638409d7795fa16b4cb1a40c 100644
--- a/components/reading_list/core/reading_list_store.h
+++ b/components/reading_list/core/reading_list_store.h
@@ -48,19 +48,19 @@ class ReadingListStore : public ReadingListModelStorage {
// Perform the initial merge between local and sync data. This should only be
// called when a data type is first enabled to start syncing, and there is no
// sync metadata. Best effort should be made to match local and sync data. The
// keys in the |entity_data_map| will have been created via GetClientTag(...),
// and if a local and sync data should match/merge but disagree on tags, the
// service should use the sync data's tag. Any local pieces of data that are
// not present in sync should immediately be Put(...) to the processor before
// returning. The same MetadataChangeList that was passed into this function
// can be passed to Put(...) calls. Delete(...) can also be called but should
// not be needed for most model types. Durable storage writes, if not able to
// combine all change atomically, should save the metadata after the data
// changes, so that this merge will be re-driven by sync if is not completely
// saved during the current run.
base::Optional<syncer::ModelError> MergeSyncData(
std::unique_ptr<syncer::MetadataChangeList> metadata_change_list,
- syncer::EntityDataMap entity_data_map) override;
+ syncer::EntityChangeList entity_data) override;
// Apply changes from the sync server locally.
// Please note that |entity_changes| might have fewer entries than
« no previous file with comments | « components/reading_list/core/reading_list_model_unittest.cc ('k') | components/reading_list/core/reading_list_store.cc » ('j') | no next file with comments »
@@ -48,19 +48,19 @@ class ReadingListStore : public ReadingListModelStorage {
// called when a data type is first enabled to start syncing, and there is no
// sync metadata. Best effort should be made to match local and sync data. The
- // keys in the |entity_data_map| will have been created via GetClientTag(...),
- // and if a local and sync data should match/merge but disagree on tags, the
- // service should use the sync data's tag. Any local pieces of data that are
- // not present in sync should immediately be Put(...) to the processor before
- // returning. The same MetadataChangeList that was passed into this function
- // can be passed to Put(...) calls. Delete(...) can also be called but should
- // not be needed for most model types. Durable storage writes, if not able to
- // combine all change atomically, should save the metadata after the data
- // changes, so that this merge will be re-driven by sync if is not completely
- // saved during the current run.
+ // storage keys in the |entity_data| are populated with GetStorageKey(...),
+ // local and sync copies of the same entity should resolve to the same storage
+ // key. Any local pieces of data that are not present in sync should
+ // immediately be Put(...) to the processor before returning. The same
+ // MetadataChangeList that was passed into this function can be passed to
+ // Put(...) calls. Delete(...) can also be called but should not be needed for
+ // most model types. Durable storage writes, if not able to combine all change
+ // atomically, should save the metadata after the data changes, so that this
+ // merge will be re-driven by sync if is not completely saved during the
+ // current run.
base::Optional<syncer::ModelError> MergeSyncData(
std::unique_ptr<syncer::MetadataChangeList> metadata_change_list,

Powered by Google App Engine
This is Rietveld 408576698